# sadm

sysadmin/devops/deployment tools

[![Build Status](https://travis-ci.org/jrmsdev/pysadm.svg?branch=master)](https://travis-ci.org/jrmsdev/pysadm)

[![codecov](https://codecov.io/gh/jrmsdev/pysadm/branch/master/graph/badge.svg)](https://codecov.io/gh/jrmsdev/pysadm)


## install

	$ pip3 install sadm
